@@ -48,12 +48,12 @@ class Builder:
             key=configuration['orchestration_artifact_builder']['type'],
             configuration=configuration['orchestration_artifact_builder']['conf'])
 
-        self.__build_pipeline.packager = pf.create(key=configuration['endpoint_appender']['type'],
+        self.__build_pipeline.endpoint_appender = pf.create(key=configuration['endpoint_appender']['type'],
                                                    configuration=configuration['endpoint_appender']['conf'])
 
-        self.__build_pipeline.packager = pf.create(key=configuration['prefect_file_packager']['type'],
+        self.__build_pipeline.prefect_file_packager = pf.create(key=configuration['prefect_file_packager']['type'],
                                                    configuration=configuration['prefect_file_packager']['conf'])
 
-        elf.__build_pipeline.packager = pf.create(key=configuration['package_publisher']['type'],
+        self.__build_pipeline.package_publisher = pf.create(key=configuration['package_publisher']['type'],
                                                   configuration=configuration['package_publisher']['conf'])
 
